
# q-expansion of newform 36.23.d.c, downloaded from the LMFDB on 16 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 36
weight = 23
poly_data = [1168838172864011361183920640, -1820809561188275535801600, -95573988251584922880, -404504858109047040, 13335465927292608, 12622768560288, 34835133568, -45742928, -63342, -5, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-1636659059392911125462272, -61562952760080779264, -895027249776424832, 12908483991246784, 11236366738048, 36484258480, -43398024, -61708, -43, 1], 1180591620717411303424], [[2302423228686168260435438848, 1523787046507364768565248, -11898641773982698061952, -28247617586236505024, -55549235242039936, -7652610062256, 121931458312, 170893900, -988677, -1393], 1180591620717411303424], [[27593553331289735435382707776768, 24032185179843052133514758144, 11580564266860208920772480, -71290363985742425996224, 22198082286681163136, 339465165420882000, 1577696656717576, 2146652109388, 489570299, -6096753], 17118578500402463899648], [[55009075032805860787616383418112, 52482773349181064923175294976, 23637358899135621951115904, -140755436198522063265088, 47331805667906368640, 680949211690220656, 3148083807212504, 4283018714884, 1020160953, -12086699], 17118578500402463899648], [[-5378175702107072383589388706560, 8650873984606682127292418048, 24360763063509987282405248, 49221697455950682144832, 1288612082218610048, -47785692394900656, -126807295357304, 549515927948, 2031061835, 3804831], 1180591620717411303424], [[368822261532111414456721437639936, -2358173176445548895369071425536, -4753959515099724141866523776, -8204321434881756107468224, -1059483253208692754048, 1069235009326248400, -14914477092328248, -166860558967572, -430529850525, -614770089], 34237157000804927799296], [[1621999846430617270171814563580160, 4493340951566728127416875329536, 6872733942124607500417202560, 4427253978191363676215104, 2533727750357499545472, 23417071810689250320, 135206600910155624, 351133130116060, 518055938367, 242467523], 34237157000804927799296], [[4556134319598271230259722053428992, 924030788830970387622881646592, -4207002091658208735707181440, -19898036271345039577922368, 2867574214888015978624, 51199605647793671920, 218835399004886040, 134260940242276, -407218243951, -1603734067], 34237157000804927799296], [[1517266076664313261098620244846336, 5599853190563829305661506836480, 9165653191408862908007870080, 7449915511203182905406656, 2997329546520227512448, 23754934471557765872, 146588995786891800, 427558858031716, 710043676113, 512356365], 8559289250201231949824]]

hecke_ring_character_values = [[19, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [29, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[-154, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1709110, 3886, -1, 0, 0, -1, 0, 0, 0, 0], [3, -141318, -10, 7, -3, 0, 0, -1, -1, 0], [4234, -2886178, -10520, 1971, 110, 8, 24, -18, 142, 32], [-53122949674, 92949788, -216897, -1918, -734, -1753, -250, 24, -112, 24], [-1405819335816, -692194857, 3832669, 63067, -117, 26649, 4305, -1212, 5656, -1212], [655810, 8851783382, -1552904, -798489, 118774, 26440, -2600, 8422, -36218, -8928], [-48002133, -147102619886, 118044238, 1399359, -2907387, -656560, -126480, 131679, -97121, -45760], [1446447091804470, 4202528073558, 824543887, 145862200, -66572872, 39860207, 1364136, 885408, -4131904, 885408], [-1135246960, 7620982121528, 2868968664, -278518176, 104142656, -13742800, -2439280, -8030472, -11362632, -666432], [32458770624341270, -18035873036108, 14239058079, -379246742, 294395018, -1306437593, 18889150, 6355704, -29659952, 6355704], [135545734300302970, -52287687543662, -5052855154, -2338038630, 1096765498, -6378476970, 5732430, 38652216, -180377008, 38652216], [-25243737996, -197168675152622, 61127373488, 7269453515, -3412414404, -358188720, -74322960, 77677340, -84394660, -32414400], [84593320154, 500620476050468, -206213504820, -5412497598, 8541658486, 1538570160, 138577680, -356609718, -925136118, -113705280], [1142434809798165090, 301955982382512, -722060136611, 3975882058, -9335935382, 113699549797, -816887970, 719372664, -3357072432, 719372664], [1229021715736, -5663215236566794, -3105013776816, -555170388107, -102213163864, 18792908352, 1627574976, 2147950296, -5251933224, -1479976704], [5824173070456429510, -8134883871450668, -3137574485881, -318297257190, 129586506042, -68242407985, -3766281010, 1793398584, -8369193392, 1793398584], [4111425093570, -4478681725365858, -10149054043160, 3827677608251, 56340672150, 80590075560, 2972607480, 34190947510, -25590875690, -11956364640], [-10397686144519, 31794458371610790, 26273827548346, 8420492126805, 706495416919, -135746713168, -21116650224, 53966834325, 41896995925, -2413967680], [8303038734360620176, 80255691416485773, 4804572656663, 2171885492297, -1007982773159, -3417344566613, 14828343835, 6502680684, -30345843192, 6502680684], [-19751155961530, 1566337367469588, 48667288996684, -40501162395666, -1246889517574, -205241300800, -70199289280, 140216252638, -145937471522, -57230744832], [-3934565816528, 73715082550449706, 10040470063984, -60232906448269, 93033282608, -197121167200, 31044588000, 287295685920, 701728969120, 82886656640], [-342066814545425125952, 772909874896689595, -290916248218399, 15173729028255, -9425602315505, -21025426630803, -295332660579, -28561585548, 133287399224, -28561585548], [-2042990948626909520144, -346131859613414283, -254342579316409, -8980028983807, 2959693658257, 60299021069371, -527708973245, -670513232628, 3129061752264, -670513232628], [2045118075162343962802, -1652887378059988904, 219128511716597, -38872410025710, 19106426285746, 74202283755165, 248533961910, 686558639832, -3203940319216, 686558639832], [-502693966975933, -2880224146464603486, 1217702288552766, 126098299496887, -53408903497747, -8373088348720, -1051206524560, -4683620587113, -3668977910313, 202928535360], [-1013954073000346, 2560044789511042350, 2533495958816536, 207018359493399, 35040656561506, -13973351122120, -2061089295960, -5875890701022, -6330164650622, -90854789920], [360896959457877384714, 3867423600610913978, 352774461699265, 127395391248600, -60470365695912, 47235223258273, 663133406344, 382248428064, -1783825997632, 382248428064], [2611769156029587532190, 160107999732972992, -4689555291746736, -68273191712032, -7088721158432, 280259007280592, -5542623062880, 1834682507904, -8561851703552, 1834682507904], [-6831406989122028, 16746701230101079312, 17223245741543040, 3959628373760980, 377464534081788, -100751690426640, -11216317078320, 46692039408876, 68929510287276, 4447494175680], [-14141352942139054, -1678019501001332766, 35214247829284808, 4349485807518137, -13339756548218, -194554018096088, -31863868959624, 51856048751814, 23362984130534, -5698612924256], [9430836927674848883546, -14562123969854710942, -46637641998345042, -1756465919919478, 537320668866346, -3712238454529738, -54159438343650, -3926138167176, 18321978113488, -3926138167176], [-4412335756368132, -38355070622282863070, 10851499860010288, -686844630760485, -587018287813548, -60659483041104, -13469732313072, 174819958511380, 141191315360980, -6725728630080], [-145419581128016811837218, -5461473881530395494, -23756241299202637, -642737295940260, 149979835086876, -9522189133213, -31386661324524, -11514524373936, 53734447078368, -11514524373936], [-36362844514562059, 25552286060268314702, 89894115869008402, -23641059364834399, -640091422365157, -546429845732368, -72893455799344, -190201719408863, -154026064271903, 7235131027392], [270282885847909290470638, -176389334865946177328, 24802557181563755, -5554734500056122, 3005509194762150, -8482893309349981, 23497078603730, -26615623697592, 124206243922096, -26615623697592], [8968826934813836, 21961919582996268206, -22090745204889808, 68196979304326597, 1938181486259204, -8656271213200, 68164863621200, -692191971273340, -206381654711740, 97162063312320], [655643193074977, -328135114951649096610, -3651513017838414, 69149404012575245, -4082385369338977, 138267637389120, -58695696267840, -29000333751723, -578137845015723, -109827502252800], [-277861504445700589993070, -342317997893400937088, 198368818723427429, -5307496143519222, 3563841033927978, 13127233661237357, 272731088849310, 304467923065464, -1420850307638832, 304467923065464], [-584863833398308, 543316446917345133626, 5325317169980320, 52065976396449383, 11143122783317140, -866146935504496, 301897220801712, -1287193755491964, 1692233725624516, 595885496223296], [1288545737249274405066474, 1157450533135089167698, 215357176753646881, 47271292692624320, -21678633704155712, 80274761802250785, 182996359759680, -270895166018304, 1264177441418752, -270895166018304], [224069305926308756, -231062632460586774432, -559049485530378480, -264242308083437516, -7725858625209380, 3394234551403152, 371329021454256, 1937124837566748, 1142193436343388, -158986280244672], [-7402613689856585333724992, -16186720601617103027, 691534647543592847, 10187579765728377, 1342859309097609, -45594610953495325, 774360451917995, -495284560409940, 2311327948579720, -495284560409940], [-9109339907496115488448210, 2869854088453614241538, 1592033469573538731, 116109248416295972, -44188551228639388, -33970583002853637, 2081002373551980, -119843841677904, 559271261163552, -119843841677904], [229313434049911443, 616808550194453040586, -548426207550743994, 535437101940632503, 25942111566644109, 7411938197954016, -498967649035872, 6405842116481631, -4498869624723489, -2180942348241024], [810696460422927124, -3042389247517102594506, -2042597897553900544, -672411008911550463, -55388877757318916, 8170094536200688, 2308511892731344, 3223956049657964, 11213444762576684, 1597897742583744], [2406016081741370320, -21667524620586797049592, -6202815872040880152, -842809231782320768, -389386102140912800, 30951650178304720, 3650390418997360, -21129288136739352, -26528205382062552, -1079783449064640], [4205469643396626336, 527433604381663654866, -10461916191666769696, -695149764035167001, 4847435424934944, 69561119862629440, 6262545314147520, -11950987560507648, -37674290224104448, -5144660532719360], [45145483574170975315063042, 21846887322172710541990, -2501883157251667891, 713932302443836260, -370783751421822300, 1097514657447310493, -3765264325866196, -3761159265256272, 17552076571195936, -3761159265256272], [73639538272794806637222400, 7085063225654089515307, 4891833792469405169, 325590692053172943, -118624929152460737, 80194882361171517, 5628760121161005, -2676520971733836, 12490431201424568, -2676520971733836], [-525637928748966338, -40994559863552200050940, 1036368310543082652, 8057868926843242630, -488689841740722622, -24041957451824256, 494484254001792, -14593060326114090, 12910286903722710, 5500669445967360], [-120235306559262074376384728, 15471012884030247022585, -2533541991807091405, 383986526047166325, -206006692233801915, -276388097390238025, -1785073965712225, 850746505796220, -3970150360382360, 850746505796220], [-10066341654638787528, -27233938424165328029226, 24719041187641726224, -7912983091639581243, -694321448937149304, -170243934384359616, -18079250275326528, 52814248268613624, 96503430725687544, 8737836491414784], [131787120812131308869926318, 48086507900944060313128, -11222248021640195608, 902825792037563112, -453974920598001816, -3645467419170325240, -13946572874504520, -31090834978256160, 145090563231862080, -31090834978256160], [-12226058357143929623, 11699903589770151026902, 30217716072796095082, -12593208113452467163, -254713092183683257, -193522124565647920, -22051643963414160, -45409094752296267, -6248477930547467, 7832123364349760], [-172953700982142150960835042, 15390906918144769033730, -25746717263640747069, -334308723475734700, -97086402363684460, -1942704509447486253, -16631787826400004, 55106168198806512, -257162118261097056, 55106168198806512], [-15573014621409391798, -199543321333178513201644, 36924506507016358460, 486922553088933778, -3588706387354684570, -225379289151411376, -53585195557658128, 14853254493242666, -134863825258952854, -29943415950439104], [328808602910210575152637390, 249147443097277206831672, -19189439297681946661, 6978627966926799998, -3573982094004295202, -796706637191624333, -5644208125051910, 16934385080490984, -79027130375624592, 16934385080490984], [393456620681436241188680888, 98420021414900999219375, -53962659704716919715, 2755933549162816835, -1891312951223037965, 10197312266991427385, -61800862777494135, 39402553619265060, -183878583556570280, 39402553619265060], [48963935022290631322, -130731440762244818046182, -122064436437486083752, 3292896137900073661, -1546650362191677122, 800189319053656360, 65914666533487480, 419251644213269294, 80464990894025294, -67757330663848800], [-492828999435499441846295282, 368837170899877762195762, -76479170340229276165, 9913349667401724948, -5458469266714335660, 4515178730909772299, -77562161155196100, -832805115988752, 3886423874614176, -832805115988752], [-17355141101901016278, -306533507646051248861434, 39527563712774807352, -53522798193631460761, -6796831324910410962, -392127475719786840, -37822433860006920, -114131208472692162, 13239230227046238, 25474087739947680], [74921473453958011155, -89708372735951439791366, -189033133097285844938, -48155951282030422953, -2892178815077438547, 920949110632850240, 181146050627398080, -1183150788923036241, -836077545164099921, 69414648751787264], [549266699826051892867646118, 675832943360862365519118, 293908181386091216722, 25312553876527636102, -10243026221738074906, -9418399925324887030, 426636796516827410, 127019456764812360, -592757464902457680, 127019456764812360], [-79288428537351661595995098, -367619271792431382036642, 135327643912183931815, -6716812833857246048, 4583743833312087200, 12090187797994399271, 78167710425631200, -253146105394186368, 1181348491839536384, -253146105394186368], [-200423480932134080150, -918684872829256155688862, 494447086749485409864, 325875819655310919489, -8766998677939096754, -2844263768658578360, -479445426774680360, 478795657143832878, -33058561620351282, -102370843752836832], [1569149212537776100680036842, -5414710025987497904468, -269212297375729390092, -8777149110740503652, 3099140079105625436, -37199926866446132060, -372604511928331820, -399704065153951920, 1865285637385108960, -399704065153951920], [352996404878340663076, -360575572831903841403930, -880528799798594293824, -337380285654357533767, -10801315272142396756, 5539255025444723760, 540440654076712080, 2445069424303742364, 688898977396003164, -351234089381547840], [-3066171388309172864632579614, -1816160857759072901891794, 536985948996115076461, -35464224488745481380, 20045603114985118236, 89024468115248459293, 564605307288191764, 478744809445012560, -2234142444076725280, 478744809445012560], [-6811729475127250511384141882, 1085061089889314632577932, -1038414200785882710940, 17579927732512376988, -16903973345233948580, 67815124784692605204, -1278655554669396780, -69618221072936112, 324885031673701856, -69618221072936112], [36447974937102257837, 266195355476690131964958, -101373773567066597054, -482455985290954342791, -11020410703205459741, -58231812751006096, 169378376932102992, -4849485961746310407, -3605605510470583367, 248776090255145408], [-152154976761963705786, 363367127426520189572236, 379784842955353531172, -198844854839763121282, -4833493315361889654, 1563306393392593200, -1376810866200409200, 1802632372991505254, -9398350083803952346, -2240196491359091520], [-9194985601890589497804656362, -992916432957532517761052, 983222876734492109967, 19015910388890957722, -4926734219554085446, 304069491374076251095, 947548613658153550, 556886475489389880, -2598803552283819440, 556886475489389880], [-908672498391929812524, 1150721196793432343354570, 2267425264294231027776, -85800313281140195305, 13523231191705417404, -14652826454222221968, -1369001090999343024, 1936764863830974060, 7006583681057794860, 1013963763445364160], [-1701598736789378646736, 3838187402255752002856288, 4250847930357090738080, -313213747468374804048, 37403409277880493136, -21499842703267844480, -4124261159484224640, -938907049146047568, -8308892462267775568, -1473997082624345600], [4907234140045595728920633066, -2253738371595238859138388, -1737557156957058864575, -91096572824268766730, 34690380887502376662, 91488408977108651577, -2909914541017083294, -2843484350110247544, 13269593633847821872, -2843484350110247544], [-15987228058615123365046924262, -11718727047226392677051598, -328882289137338335575, -365164532305970313232, 180539462420148713200, -107083115519261747351, -1467864042113272880, -2646463249729351872, 12350161832070308736, -2646463249729351872], [-12415978914219863021691001496, 1632834761491533382157119, 162491350213135638293, 33718425309633919395, -13124334087922152621, -200494238039976403855, 396308181048513705, -409014843557459292, 1908735936601476696, -409014843557459292], [19154102105260247786119286742, -12975063885831206048595210, -3681083705347057603766, -494915457392177456690, 211954515073333692590, -264995198186354949982, -4290372072846361366, 2687927699736595368, -12543662598770778384, 2687927699736595368], [-438858071121595788994, 9541992367576218116814610, 1138117840410031131896, -2343260016629690273955, 92778318920739855274, -3096740617425992168, -1235635585321053624, -1827032333598526230, -7379740813419909430, -1110541695964276640], [-2553837355842855237054363446, -9173572927636901380245902, -5804584087044308104639, -288347763089535290400, 87470988356932774368, 1128857481122556720065, -8520234999890197600, 466364360664206976, -2176367016432965888, 466364360664206976], [100825362215937830158, 17994476659894478503123828, -96734965398182680948, 378424514310752006134, 300593503727696252498, 13939090669186554016, -1412567361708520992, -4848273631997806122, -28675335833144007082, -4765412440229240192], [-24814123457900732615068107240, -3670715860849529361719647, 10764076457883913884331, -533553999175138563, 100602561008173530957, -1276214288434783180337, 12786443239198552375, -6079024571927778084, 28368781335662964392, -6079024571927778084], [388250473976790695181, 12280552990457415276573606, -893652279156209320726, -4025071106021119313207, 127882470214769858931, -527246841409431168, 3257993969600908416, 10522273578869215121, 33855478207485005201, 4666640925723158016], [-2319009957781630950022, 9280545828628283829083414, 5789018042177164210488, -27388737022089447729, 101312122309785363742, -26128194583954763160, -6189699411601377480, -32689628294200796178, -49889329591455675378, -3439940259450975840], [66076078209588093353341541184, -3044064623341440876188301, 8420224825317172261969, -13848532418810562425, 77033034787963358839, -1002910670743130558723, 11213684029325497941, 981239157196820820, -4579116066918497160, 981239157196820820], [-49683118764446840847493601770, -23836335765334484728655578, -9589130095978826664486, -1146502417627148665282, 497124640299060026398, -2342064860502159256078, -9315023954374158790, 5498439815676096744, -25659385806488451472, 5498439815676096744], [-37623764889542515420797313362, 8167426908276680485805850, 12846992161567974603595, 568875115145420236300, -216468822132890935860, 884322630411496349115, 19392395668089809700, 20499471671563969680, -95664201133965191840, 20499471671563969680], [5027637023404737044822, 18284250070395351608424372, -12281985472320832068180, 5797001593789918568830, 445958112326572947818, 106211957139467750720, 3801748432880461760, -24263109273442546194, -103862827382747064594, -15919943621860903680], [9111960726504434633298, -32886508661039270700001814, -22970523904247175961416, -1385579647787165947667, -551492351515367165658, 129787187112157201800, 15935902549304578200, -33047974212505677162, -51283843479530831562, -3647173853405030880], [-2560281969427594070304, 23646009381152242634844344, 6494618701118334575768, -13411578760131955110288, 131387451119284197552, -62101393108393935248, 2430211142547970896, 75713976448129275624, 154826847554359007144, 15822574221245946304], [824093080260512493583, -13661648465317864688752174, -2032443083082039641858, -1589727583763548655229, -78244561579067898863, -61027588583459862560, 21282910483035068320, 96579349790811870091, 306587311755517210891, 42001592392941068160], [9455812325355902777024, 36974732351737063211428334, -22839804193056013645504, 14367419478119689743337, 1185327892056329243584, 131338339439368121728, 28058576230259624064, 76739284146850516224, 141810978319299762944, 13014338834489849344], [-6033630944577182932112, -129912739570756443430108794, 13749131172150187604336, 14181424074650126766213, -2086459840776597671696, -94121387037902594144, -23088995997740785952, -195639062876182107424, -263140647822465014944, -13500316989256581504], [5821365001883657238951, -14697132371119229086096166, -14388344959705450774842, 17244559938827262809227, 366605189810220213129, -8790685285268865840, 39739598556707706480, -46968140374239627189, 239999734807983184011, 57393575036444562240], [-185339247344513963089336860942, 45718202585281575646536480, 9437596048456487942341, 1246487189002931488810, -518484154471659071670, -3293261013332734488243, 18025107514185832446, 4377797227906319352, -20429720396896156976, 4377797227906319352], [32088134244599620934312811978, 100638531366626145731356170, -81209880147219532441370, 1581369803970223134610, -1414203073460890226510, 2631898685240097280270, -94777033685316574410, 2635571478077973720, -12299333564363877360, 2635571478077973720], [-23558077068909913951934, -34454843236112980003117246, 58260418706349559679656, 9218185849561644714825, -454537109467950131306, -431174264000287749080, -26242869360462863240, -38947417566603358346, 208526760910444348054, 49494835695409541280], [-107984844828039850703744876618, 296724306812781462609266460, -53823917912003257160065, 7182190058404030522370, -3879604899193755924830, -6219609493400037341465, -41860361574702555770, 5794418737473194520, -27040620774874907760, 5794418737473194520], [-40779713737730277117710, -134043535071427785962975314, 101113521841641868262472, 42934397770718314531315, -1302017320927202646170, -563039369943476138840, -98957393179945523720, 354739307596508673702, 225076925280366146502, -25932476463228505440], [-249617137619981365104772228678, 31322899387297465821584348, -111161991017319913237335, 355468915725702595862, -886002775637064284170, 15521709397654087450401, -185042878026505827390, -174533078611085255928, 814487700185064527664, -174533078611085255928], [-2243335680488227734874, 265559589787938731222465146, 9120727993048059495944, -31643681718847700257431, 4366182973375346555074, 207650686433464233880, -44306538048726479160, 1203052640236899325362, 685256187462349737362, -103559290554909917600], [-1018513555544170961620277911350, 134421601261998678150871098, -129632202162984385834058, -720338315513615646590, -404399184894360807262, -22109585432306281998178, -136257957861775787514, -42744135335426113512, 199472631565321863056, -42744135335426113512], [124389192772065783535534, -581801609852380156303395350, -312764798960127736620376, 32837743826423013733465, -7523464432987407074534, 1640212760098031117368, 253751667542871878824, 429368477663416170890, 565417390365488205290, 27209782540414406880], [271791676206886808254869389642, -11792519233505299461203828, 123218435039893327543668, 181230173056242809788, 1392316920109002963836, -24643720016098582587740, 120348873096383175220, -247293293474341316400, 1154035369546926143200, -247293293474341316400], [-133887068047218522427078, -478449997560183506153140866, 328953456338532275701608, 13140628355193121664179, -8229328728259507777922, -2328344634440217315000, -216790599788927145000, 408237831977931805374, 1219048267895659105374, 162162087183545460000], [-1421757244256950021750766442482, 198801832691972867520842152, 421855159849887658559000, 16660757039131335601608, -4877319658249100559800, 18232314258810688486584, 472914261270384687960, -133805704609082389152, 624426621509051149376, -133805704609082389152], [77402101314374788145151, -502148924815798922325851758, -198160421138607133024898, -88010390879124683187149, -10986347035909670030367, 1350466897216873820192, 29158406305040240736, -268610418163362919653, -1414968471244955054693, -229271610616318427008], [2033366674516651971585159124896, -110544122897576937435173739, 383241977135185185055087, 7308104652286778044465, -836529445143275213119, 27503485278161269459235, 424956438301990292435, -19519776013121261748, 91092288061232554824, -19519776013121261748], [51121184821742900466732, 800396485150290712620879736, -122660868427048500041048, -101553963314683053033636, 10268562611604565116468, 1134172318425738779040, 58332266062326762720, -952024572690216542132, -1677871028679667982132, -145169291197890288000], [-2179606897133588897343221582070, -404929897472874856263084782, 137303833103262853395361, -9681781641939651574528, 5865463153664108829952, -4548664815880750846047, 140674798743730609920, -38889226185894380544, 181483055534173775872, -38889226185894380544], [-1072652558671056472161502999560, 333482506899621496112579103, 47317057914345714112141, 14051872756906739119027, -7591816161004825069213, 39678201833719740874793, 150356926682353108185, 544658755054147310436, -2541740856919354115368, 544658755054147310436], [244770245138014312037950, -57182450219264550881891918, -607120043795774969180904, 168643899972177009146781, 4971886832102648410474, 3509983172119338462040, 540934254049910293000, -975201733130903324598, -698645126900869735638, 55311321246006717792], [24302618776460772250649, -1119886522879158421386027194, -68655265586954602186918, 53414743320123192993333, -16791464275196282889097, -61093385520311485072, 62105023407664011344, 489993679144821462101, 985822228518781026581, 99165709874791912896], [272483661418729334509707321904, -2893265003317772430451460261, 416236781689104478977833, -73642551778480647726705, 39134530674998144972799, 44122309802117665104245, 258132729538083965805, -224256015444803058252, 1046528072075747605176, -224256015444803058252], [135488977318942278708498, 807182284644492119852831742, -324572729560530260836760, 51714187520944807329467, 18890208699996682144902, 1988483502955733844840, 384223994476221336120, 2768020989433908583654, 3469105447811724091654, 140216891675563101600], [218691243642179335550617, -1068593234364104724287720394, -553870587037015091772406, 178573965493558488340821, -13142872128780946133737, 2409497026258631452240, 577052515778074759920, -3017986752383452274715, -1388116168195560407515, 325974116837578373440], [-869704527634391635989282088434, -505508124748569083612924118, 963478019240087173451611, 2209448665956811121308, 6538582639392115936092, -28273824576991047660789, 1153477979579713574100, -51423566506723505328, 239976643698043024864, -51423566506723505328], [420635970272396557906136, -143577201231158687381947894, -1043214230539785999763056, -171475172486307796628277, -1699256456374579264664, 6749769326460954919872, 670369315617626262336, 3222175524168057062616, 1164991407030485979096, -411436823427514216704], [-97276194113342943196955327014, -4482340013590403778124774, 321011667857660586292377, -8214535040852486274520, 7551963401185295147176, -153224255573451439326535, 550835606370441267320, 47906668464288080352, -223564452833344374976, 47906668464288080352], [-1823342776443956876402779288320, -3556184747291721065883450867, 284844731381701407075631, -102498437950255423211783, 51196099783921466939657, -6842316531655935264637, 325524534461766817835, 765539528896845523116, -3572517801518612441208, 765539528896845523116], [-2256830691082437138065541986502, 2551036696099670167210822788, 38386311278072454412777, 76382646074708549193262, -36441319249947821498226, -14796128875661916127935, 125776079528492529930, -329103271931029995480, 1535815269011473312240, -329103271931029995480], [-761269340757593834109824, 354144770160201130093714510, 1882285306744240006535936, -448473881089029026805287, -14234990572871886399616, -11665446892285942062080, -1468998510508002186240, -3116093690022679921536, -1733636371292753163136, 276491463745985351680], [-849011662384488150791468, -1791140673783730560559177402, 2094410982603591368708256, 32965525702361633572489, -36679782105149296916996, -12171862513265718266576, -1994297429944033140848, 1754075392507844628108, -34144103834669091252, -357643899268502743872], [-8138409463093567475374462466966, -7697212652720676316360809356, 1680715032580815955623953, -217903053675864388703730, 120596289362912120536174, -224295258580923864186135, 1900454160376824617130, 249949241459800174248, -1166429793479067479824, 249949241459800174248], [-555373170386965352109890731466, -625084467436306635256229372, -1579103858271963159537745, -62286836931937769089350, 21930321222595458688218, -136232258254562340469897, -2166048716184861441106, -1717489204174649474376, 8014949619481697547088, -1717489204174649474376], [-885382939301276482043742, -673198070335139514644331476, 2177638419756888957799380, -68924200818103623892358, -23992892927021904575490, -16380491866489264953504, -979646580919106783712, -9836406616772686954086, -313440816717169486566, 1904593160011103493504], [1030367264046259810854401, 6109165212811034725099383246, -2504411982349905899692958, -48883407639667429446003, 118657919755940501478239, 11849350925707350807200, 3671259237575061010400, -606396166610058851195, 13243067570708017414405, 2769892747463615253120], [16527313846718123630944384286202, -2996045520669632077852215502, 1004278992436902886630345, -89017139575823807824848, 56669180331050376575280, -244682636051816853135479, 758214768822368552080, -2552546310279909555648, 11911882781306244593024, -2552546310279909555648], [588378080869259240243568, 2537035023143687701163558830, -1457723571451979221392672, 431026008336831377296105, 37830918769863634173072, 14324342393442440741376, -162732288913464556032, -17006843518494772362960, -32470311934331464996560, -3092693683167338526720], [-451948635071755997990351, -4563420862229404589952177490, 1121000382458435489254146, 1172037139224727464239869, -37318168442624255465809, -7326916169428800910560, -935822835877122629280, 16491652488190073105973, 17267808806479015611573, 155231263657788501120], [-3175739458225050495115206, -6415794937686923664000751652, 7828785574891921866632548, 37347990759848933094834, -141358211789660306024538, -43515889085030421361632, -8038438647390371453856, 2163341274801453254578, -10589840171900725560782, -2550636289340435763072], [3956139102017029022713968427842, -5912203319659245741519907658, -5574590107078129901309507, -293984254512616083446092, 95685391522927403922676, 43785620437167553911885, -6314896828775084101860, 3621143416356208637040, -16898669276328973639520, 3621143416356208637040], [860555321905801656489303664730, -8584297151613162081955481422, 4457626489835541623237166, -216624477188985118944070, 142711743410658405626458, -528358827956810637152650, 5611915270375809693870, 733392155744794184376, -3422496726809039527088, 733392155744794184376], [-16329374143807569341046368357664, 4996218193208182624035494781, 4286538670630679789491711, 125752254352457157490345, -21694908012473376785479, -1164674958732788589099757, 6856176936773622240059, 1194328561861179741420, -5573533288685505459960, 1194328561861179741420], [6744375358138346277345122029754, 4556057104216616466383197412, -5411667365112648329349783, -16418090569851098150962, -25551369481271418770386, -464691786557414245352127, -6422125195302683836950, -2817670236448403680344, 13149127770092550508272, -2817670236448403680344], [1403019383816788664967036, -7412443880354756207210488106, -3466462703511520046501984, 4166388472709237969865465, 11660457785743112697204, 18801582781788344102160, 3361445517207378085680, 17188959946662744008164, 21917495785326046505764, 945707167732660499520], [-27418032390486920540614030761790, 14323967955704755047811347128, -1042392286487122048019859, 420028909353049482260642, -210478043610624712027838, 90333104367559074074453, -1088461359535547780250, -2333438789252149296744, 10889381016510030051472, -2333438789252149296744], [-67493233079032712155401752248422, 16315585097542354477412963010, 3934723897742757672030046, 598738008876415425755530, -265042689055193895232470, 287925763949122555632102, 5355379506285819415326, 170700496886120666232, -796602318801896442416, 170700496886120666232], [701943211126903261171206, -30510070155549468835728362222, -2007975193407048980790600, 1272164200787585068771669, -470565106002587122514430, -9758748717510200362248, 4079475552730888270056, -13699141611946905758622, 24615935974679512494018, 7663015517325283650528], [90699200089378244573454212943882, -8435755832216777797651130484, 11375006597954821008960577, -6300498821755096361450, 90144750211833705828086, 96978385789256239948985, 12997272180226063776450, -886669986877674035448, 4137793272095812165424, -886669986877674035448], [3917609173453587752029629, 4101553315076089891758546182, -9705580446914991222766070, -1507598629898313279913031, 71932277476981968191811, 53725361622959243546880, 9286278413290881872640, 1138408110157984689217, 12416995380234914250817, 2255717454015385912320], [4925167324558776483457390, -38389719182641180735728115530, -12501775694270339539230424, 2646414237547251224212851, -534188559669914921647270, 68046118597207018310200, 7768852574524858425000, 16808034766721143006026, 3143884191188133670826, -2732830115106601867040], [24647655139557756024604673141262, -11422859548644263526119398880, 4638567285903837342399739, -224241567851780527112170, 134936155634601142856950, 306138432034739270920563, 5805097795974672548034, 5265093164161585504008, -24570434766087399018704, 5265093164161585504008], [-6592788392700905404461195, -31084900883371509431655845834, 16098335463302824466424218, 3604293861980234513360273, -511822135554368163840693, -106302602734244464207040, -13614064195257696022080, -30429710709127465022919, -19425557341686872970439, 2200830673488118410496], [-136332401740622949765104530148530, 12866546211982947550269540088, 10402566616039314629157051, 638493347798443601472382, -241396401323969341250338, 430264109243228796316243, 13578934501448099420410, 3675106476762418851816, -17150496891557954641808, 3675106476762418851816], [-138738622856822943731688761708310, 26579952188404265153080830858, -4095858688338343750819034, 558698037073686655986322, -303063362128289098470478, -1502998086530237615161522, -510600931648366900170, 7198389718493430221016, -33592485352969341031408, 7198389718493430221016], [-8326478059877574755450396, -19959877259923614480950578086, 20400939600527908122860576, -1155713626516187888158353, -448186314264650816922836, -154175014952826797268752, -10520408276799298051376, -58354012622322551242756, 22178144392909159666364, 16106431403046342181824], [10044224943894309863023048, 14522660114162483917530832888, -24783805218961859512740040, -2151189898648308371788520, 294632191934652214690472, 158335692058738123361680, 18810311085346825406640, 35843211182786395917024, 9179696721476050401824, -5332702892262069103040], [784652210563892635804905374434, -23395810691576929118712882338, -4545027934130383106738563, -488107710189542117361972, 203578864278072531756684, 2996552537377930041787373, -13026086918315449875100, -15598084994947728446064, 72791063309756066081632, -15598084994947728446064], [81886221528566545616449228816982, -26043833473182162113677439404, -30391193310411498153345588, -1766891188463025033199900, 648149308641586467636516, -3581784669635719492224740, -32808486297665806281300, 7779220466505285224112, -36303028843691331045856, 7779220466505285224112], [-11754828445714115049635954, 11076584033980464043236766662, 29381364499271530023586600, -2476503974205208845926837, 55835494668412985698234, -137285134160347914764360, -32803322275837377265880, 105726735028567877998378, 13388613258054151901578, -18467624354102745219360], [-15581393660207919001519677, -1112276822602346407109419830, 38611190548013601753750406, -2689244529089192074810393, -166614708468858703594083, -277234643638796972548960, -18734068870613002152480, -20337871377177118275345, 125758290167328839206255, 29219232308901191496320], [11761201971333836681114224, 80275146217339123915221923778, -28324781748336957650408352, 7133541343172894252289695, 1680286499570390820462736, 205871667141445265132800, 24449580514199779321600, 51377974036502628650160, 16653370494455818768560, -6944920708409361976320], [-12871415444355953499092994, -12462476903790068406175574164, 31803055175825866111040804, 8783110691559581740332918, -196631644909239711133134, -179414569946782165606448, -29473719539758301921424, -107109609066189576910674, -134011075897715524754194, -5380293366305189568704], [-23358642837215983467143843, 89782161235819959598086772846, 58855469973511419282479890, 3291266223707044340777993, 1469570115542991410713555, -340169655719848326518576, -38464031488829362890128, 30831175615789997079481, 101752610913832783367161, 14184287059608557257536], [304240785228499447386474682608320, -29639184518259065021465646637, 4987784254408456133661777, -744118762568229599321305, 397709949046650533830423, 439589738036993694204797, 4084288820506330060341, 316697495560733372628, -1477921645950089072264, 316697495560733372628], [106954278035564871773167233126560, -44289449980031937375671663483, -17029694422787808474094881, -1933146904772946831697247, 867857205391542420941873, -2913756086423667503593133, -24485580704655475728605, -21331774441881034351476, 99548280728778160306888, -21331774441881034351476], [-320000412848683855299010725842362, -58499428147175294516283808450, -30133783880930278134289785, -2421623880955471168604800, 920177089151428940241280, -77959781094193241236345, -34307560213187993520000, 23871427037853418652160, -111399992843315953710080, 23871427037853418652160], [-11207570631972400426066370, 55735319567856127487469498234, 28430520992142259944862888, 3091689393880194986019265, 918096292170085032564170, -105808655137269210244360, -32958984713768633331480, 66856276478423501608698, -58047961380687721467302, -24980847571822244615200], [-52512669435381890104937130550534, -110324395500818729835023412478, 10883710903997417335635726, -3297834250691052192740182, 1689479575666079098768202, -2027183895612085335102954, 12300190342469452099710, 13901924790175918676472, -64875649020820953823536, 13901924790175918676472], [14587616805260959978913243, 3178267483422901957096941290, -36135581401413598994405946, 4843601691936233604570495, 323516565131862165499877, 197115247561853661846080, 35721821963644723547840, -18139508643893310542697, 34797997539766092446103, 10587501236731880597760], [-3803152049897915355308888, 99712033069502618055504669342, 10174692869004683406265088, -7612345349542206262894359, 1367551299946034145005432, 19767099225456902885344, -20126540860269698322528, -14662698319244848327848, -175315583566589639470888, -32130577049468958228608], [463513847303633086066085493058776, -77961290792335529784739930137, 52124557047064473649947373, -950798968582506040420373, 989702623972525656374811, 1786718790402576333328617, 36066467039777830584705, -98778036678605907304956, 460964171166827567423128, -98778036678605907304956], [46985865788961485966918183, 65223112142875281584892554642, -116719781318286736235394978, -52000988374697592866935461, 240183377859594971933977, 640641039819911549872320, 108641844095495260944960, 14500973645306221185171, 134352842493861497927571, 23970373769711055348480], [-42665484897012649387783068, 209916937685584841359006892408, 107543151610830658524735816, -2389755370212598688933356, 3185122249022311683673884, -670803887254995609734016, -53629103674080445719168, -128212453101451897624332, 167187708434980592075508, 59080032307286497939968], [-186401903925254320169034343937562, -222078008882117889332069184468, 83009294967025759625737735, -4143560677650696577746302, 2656642537196245990679330, 7720286752626419023159919, 71988187234874638118150, -41272581650898548484072, 192605381037526559592336, -41272581650898548484072]]
